pldmd: use async instead of event loop at start

This commit changes the first command to async that pldmd sends
after starting to discover Host state.

Also uses GetPLDMVersion as the first command so that Host understands
bmc pldmd has restarted.

Change-Id: Icb556a89f3cc9564450cc344ba9e0e8b56421fd9
Signed-off-by: Sampa Misra <sampmisr@in.ibm.com>
diff --git a/host-bmc/host_pdr_handler.hpp b/host-bmc/host_pdr_handler.hpp
index 4629f5a..ccafa66 100644
--- a/host-bmc/host_pdr_handler.hpp
+++ b/host-bmc/host_pdr_handler.hpp
@@ -162,9 +162,9 @@
      */
     void getHostPDR(uint32_t nextRecordHandle = 0);
 
     /** @brief set the Host state when pldmd starts
      */
-    void setHostState();
+    void setHostFirmwareCondition();
 
     /** @brief set HostSensorStates when pldmd starts or restarts
      *  and updates the D-Bus property
@@ -269,10 +269,6 @@
 
     /** @brief whether response received from Host */
     bool responseReceived;
-    /** @brief whether timed out waiting for a response from Host */
-    bool timeOut;
-    /** @brief request message instance id */
-    uint8_t insId;
 };
 
 } // namespace pldm
@@ -162,9 +162,9 @@
     void getHostPDR(uint32_t nextRecordHandle = 0);
 
-    /** @brief set the Host state when pldmd starts
+    /** @brief set the Host firmware condition when pldmd starts
      */